@@ -81,7 +81,7 @@
 #include <sstream>
 #include <string>
 
-#include <libwpd/libwpd.h>
+#include <librevenge/librevenge.h>
 
 #include "MWAWPosition.hxx"
 #include "MWAWOLEParser.hxx"
@@ -98,13 +98,15 @@ class CompObj
 {
 public:
   //! the constructor
-  CompObj() : m_mapCls() {
+  CompObj() : m_mapCls()
+  {
     initCLSMap();
   }
 
   /** return the CLS Name corresponding to an identifier */
-  char const *getCLSName(unsigned long v) {
-    if (m_mapCls.find(v) == m_mapCls.end() ) return 0L;
+  char const *getCLSName(unsigned long v)
+  {
+    if (m_mapCls.find(v) == m_mapCls.end()) return 0L;
     return m_mapCls[v];
   }
 
@@ -113,7 +115,8 @@ protected:
   std::map<unsigned long, char const *> m_mapCls;
 
   /** initialise a map CLSId <-> name */
-  void initCLSMap() {
+  void initCLSMap()
+  {
     // source: binfilter/bf_so3/source/inplace/embobj.cxx
     m_mapCls[0x00000319]="Picture"; // addon Enhanced Metafile ( find in some file)
 
@@ -242,7 +245,7 @@ MWAWOLEParser::~MWAWOLEParser()
 {
 }
 
-bool MWAWOLEParser::getObject(int id, WPXBinaryData &obj, MWAWPosition &pos, std::string &type)  const
+bool MWAWOLEParser::getObject(int id, librevenge::RVNGBinaryData &obj, MWAWPosition &pos, std::string &type)  const
 {
   for (size_t i = 0; i < m_objectsId.size(); i++) {
     if (m_objectsId[i] != id) continue;
@@ -255,7 +258,7 @@ bool MWAWOLEParser::getObject(int id, WPXBinaryData &obj, MWAWPosition &pos, std
   return false;
 }
 
-void MWAWOLEParser::setObject(int id, WPXBinaryData const &obj, MWAWPosition const &pos,
+void MWAWOLEParser::setObject(int id, librevenge::RVNGBinaryData const &obj, MWAWPosition const &pos,
                               std::string const &type)
 {
   for (size_t i = 0; i < m_objectsId.size(); i++) {
@@ -284,17 +287,17 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
 
   if (!file.get()) return false;
 
-  if (!file->isOLEStream()) return false;
-
-  std::vector<std::string> namesList = file->getOLENames();
+  if (!file->isStructured()) return false;
 
+  unsigned numSubStreams = file->subStreamCount();
   //
   // we begin by grouping the Ole by their potential main id
   //
   std::multimap<int, MWAWOLEParserInternal::OleDef> listsById;
   std::vector<int> listIds;
-  for (size_t i = 0; i < namesList.size(); i++) {
-    std::string const &name = namesList[i];
+  for (unsigned i = 0; i < numSubStreams; ++i) {
+    std::string const &name = file->subStreamName(i);
+    if (name.empty() || name[name.length()-1]=='/') continue;
 
     // separated the directory and the name
     //    MatOST/MatadorObject1/Ole10Native
@@ -353,7 +356,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
 
     // try to find a representation for each id
     // FIXME: maybe we must also find some for each subid
-    WPXBinaryData pict;
+    librevenge::RVNGBinaryData pict;
     int confidence = -1000;
     MWAWPosition actualPos, potentialSize;
     bool isPict = false;
@@ -362,7 +365,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
       MWAWOLEParserInternal::OleDef const &dOle = pos->second;
       if (pos++->first != id) break;
 
-      MWAWInputStreamPtr ole = file->getDocumentOLEStream(dOle.m_name);
+      MWAWInputStreamPtr ole = file->getSubStreamByName(dOle.m_name);
       if (!ole.get()) {
         MWAW_DEBUG_MSG(("MWAWOLEParser: error: can not find OLE part: \"%s\"\n", dOle.m_name.c_str()));
         continue;
@@ -370,7 +373,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
       libmwaw::DebugFile asciiFile(ole);
       asciiFile.open(dOle.m_name);
 
-      WPXBinaryData data;
+      librevenge::RVNGBinaryData data;
       bool hasData = false;
       int newConfidence = -2000;
       bool ok = true;
@@ -388,22 +391,27 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
                  readOlePres(ole, data, pictPos, asciiFile)) {
           hasData = true;
           newConfidence = 2;
-        } else if (isOle10Native(ole, dOle.m_dir) &&
-                   readOle10Native(ole, data, asciiFile)) {
+        }
+        else if (isOle10Native(ole, dOle.m_dir) &&
+                 readOle10Native(ole, data, asciiFile)) {
           hasData = true;
           // small size can be a symptom that this is a link to a
           // basic msworks data file, so we reduce confidence
           newConfidence = data.size() > 1000 ? 4 : 2;
-        } else if (readCompObj(ole, dOle.m_dir, asciiFile));
+        }
+        else if (readCompObj(ole, dOle.m_dir, asciiFile));
         else if (readContents(ole, dOle.m_dir, data, pictPos, asciiFile)) {
           hasData = true;
           newConfidence = 3;
-        } else if (readCONTENTS(ole, dOle.m_dir, data, pictPos, asciiFile)) {
+        }
+        else if (readCONTENTS(ole, dOle.m_dir, data, pictPos, asciiFile)) {
           hasData = true;
           newConfidence = 3;
-        } else
+        }
+        else
           ok = false;
-      } catch (...) {
+      }
+      catch (...) {
         ok = false;
       }
       if (!ok) {
@@ -417,7 +425,7 @@ bool MWAWOLEParser::parse(MWAWInputStreamPtr file)
       if (data.size()) {
         MWAWInputStreamPtr dataInput=MWAWInputStream::get(data, false);
         if (dataInput) {
-          dataInput->seek(0, WPX_SEEK_SET);
+          dataInput->seek(0, librevenge::RVNG_SEEK_SET);
           Box2f box;
           if (MWAWPictData::check(dataInput, (int)data.size(), box) != MWAWPict::MWAW_R_BAD) {
             isPict = true;
@@ -484,9 +492,9 @@ bool MWAWOLEParser::readOle(MWAWInputStreamPtr ip, std::string const &oleName,
 
   if (oleName!="Ole") return false;
 
-  if (ip->seek(20, WPX_SEEK_SET) != 0 || ip->tell() != 20) return false;
+  if (ip->seek(20, librevenge::RVNG_SEEK_SET) != 0 || ip->tell() != 20) return false;
 
-  ip->seek(0, WPX_SEEK_SET);
+  ip->seek(0, librevenge::RVNG_SEEK_SET);
 
   int val[20];
   for (int i= 0; i < 20; i++) {
@@ -502,7 +510,7 @@ bool MWAWOLEParser::readOle(MWAWInputStreamPtr ip, std::string const &oleName,
   ascii.addPos(0);
   ascii.addNote(f.str().c_str());
 
-  if (!ip->atEOS()) {
+  if (!ip->isEnd()) {
     ascii.addPos(20);
     ascii.addNote("@@Ole:###");
   }
@@ -515,10 +523,10 @@ bool MWAWOLEParser::readObjInfo(MWAWInputStreamPtr input, std::string const &ole
 {
   if (oleName!="ObjInfo") return false;
 
-  input->seek(14, WPX_SEEK_SET);
-  if (input->tell() != 6 || !input->atEOS()) return false;
+  input->seek(14, librevenge::RVNG_SEEK_SET);
+  if (input->tell() != 6 || !input->isEnd()) return false;
 
-  input->seek(0, WPX_SEEK_SET);
+  input->seek(0, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
   f << "@@ObjInfo:";
 
@@ -536,10 +544,10 @@ bool MWAWOLEParser::readMM(MWAWInputStreamPtr input, std::string const &oleName,
 {
   if (oleName!="MM") return false;
 
-  input->seek(14, WPX_SEEK_SET);
-  if (input->tell() != 14 || !input->atEOS()) return false;
+  input->seek(14, librevenge::RVNG_SEEK_SET);
+  if (input->tell() != 14 || !input->isEnd()) return false;
 
-  input->seek(0, WPX_SEEK_SET);
+  input->seek(0, librevenge::RVNG_SEEK_SET);
   int entete = (int) input->readULong(2);
   if (entete != 0x444e) {
     if (entete == 0x4e44) {
@@ -554,7 +562,7 @@ bool MWAWOLEParser::readMM(MWAWInputStreamPtr input, std::string const &oleName,
   for (int i = 0; i < 6; i++)
     val[i] = (int) input->readLong(2);
 
-  switch(val[5]) {
+  switch (val[5]) {
   case 0:
     f << "conversion,";
     break;
@@ -594,11 +602,11 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
 
   // check minimal size
   const int minSize = 12 + 14+ 16 + 12; // size of header, clsid, footer, 3 string size
-  if (ip->seek(minSize,WPX_SEEK_SET) != 0 || ip->tell() != minSize) return false;
+  if (ip->seek(minSize,librevenge::RVNG_SEEK_SET) != 0 || ip->tell() != minSize) return false;
 
   libmwaw::DebugStream f;
   f << "@@CompObj(Header): ";
-  ip->seek(0,WPX_SEEK_SET);
+  ip->seek(0,librevenge::RVNG_SEEK_SET);
 
   for (int i = 0; i < 6; i++) {
     int val = (int) ip->readLong(2);
@@ -622,10 +630,11 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
     if (clsName)
       f << "'" << clsName << "'";
     else {
-      MWAW_DEBUG_MSG(("MWAWOLEParser::readCompObj: unknown clsid=%ld\n", clsData[0]));
+      MWAW_DEBUG_MSG(("MWAWOLEParser::readCompObj: unknown clsid=%ld\n", (long) clsData[0]));
       f << "unknCLSID='" << std::hex << clsData[0] << "'";
     }
-  } else {
+  }
+  else {
     /* I found:
       c1dbcd28e20ace11a29a00aa004a1a72     for MSWorks.Table
       c2dbcd28e20ace11a29a00aa004a1a72     for Microsoft Works/MSWorksWPDoc
@@ -643,16 +652,17 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
     long sz = ip->readLong(4);
     bool waitNumber = sz == -1;
     if (waitNumber || sz == -2) sz = 4;
-    if (sz < 0 || ip->seek(actPos+4+sz,WPX_SEEK_SET) != 0 ||
+    if (sz < 0 || ip->seek(actPos+4+sz,librevenge::RVNG_SEEK_SET) != 0 ||
         ip->tell() != actPos+4+sz) return false;
-    ip->seek(actPos+4,WPX_SEEK_SET);
+    ip->seek(actPos+4,librevenge::RVNG_SEEK_SET);
 
     std::string st;
     if (waitNumber) {
       f.str("");
       f << ip->readLong(4) << "[val*]";
       st = f.str();
-    } else {
+    }
+    else {
       for (int i = 0; i < sz; i++)
         st += (char) ip->readULong(1);
     }
@@ -677,11 +687,11 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
     ascii.addNote(f.str().c_str());
   }
 
-  if (ip->atEOS()) return true;
+  if (ip->isEnd()) return true;
 
   long actPos = ip->tell();
   long nbElt = 4;
-  if (ip->seek(actPos+16,WPX_SEEK_SET) != 0 ||
+  if (ip->seek(actPos+16,librevenge::RVNG_SEEK_SET) != 0 ||
       ip->tell() != actPos+16) {
     if ((ip->tell()-actPos)%4)
       return false;
@@ -690,7 +700,7 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
 
   f.str("");
   f << "@@CompObj(Footer): " << std::hex;
-  ip->seek(actPos,WPX_SEEK_SET);
+  ip->seek(actPos,librevenge::RVNG_SEEK_SET);
   for (long i = 0; i < nbElt; i++)
     f << ip->readULong(4) << ",";
   ascii.addPos(actPos);
@@ -714,9 +724,9 @@ bool MWAWOLEParser::isOlePres(MWAWInputStreamPtr ip, std::string const &oleName)
 
   if (strncmp("OlePres",oleName.c_str(),7) != 0) return false;
 
-  if (ip->seek(40, WPX_SEEK_SET) != 0 || ip->tell() != 40) return false;
+  if (ip->seek(40, librevenge::RVNG_SEEK_SET) != 0 || ip->tell() != 40) return false;
 
-  ip->seek(0, WPX_SEEK_SET);
+  ip->seek(0, librevenge::RVNG_SEEK_SET);
   for (int i= 0; i < 2; i++) {
     long val = ip->readLong(4);
     if (val < -10 || val > 10) {
@@ -728,11 +738,11 @@ bool MWAWOLEParser::isOlePres(MWAWInputStreamPtr ip, std::string const &oleName)
   long actPos = ip->tell();
   long hSize = ip->readLong(4);
   if (hSize < 4) return false;
-  if (ip->seek(actPos+hSize+28, WPX_SEEK_SET) != 0
+  if (ip->seek(actPos+hSize+28, librevenge::RVNG_SEEK_SET) != 0
       || ip->tell() != actPos+hSize+28)
     return false;
 
-  ip->seek(actPos+hSize, WPX_SEEK_SET);
+  ip->seek(actPos+hSize, librevenge::RVNG_SEEK_SET);
   for (int i= 3; i < 7; i++) {
     long val = ip->readLong(4);
     if (val < -10 || val > 10) {
@@ -740,31 +750,31 @@ bool MWAWOLEParser::isOlePres(MWAWInputStreamPtr ip, std::string const &oleName)
     }
   }
 
-  ip->seek(8, WPX_SEEK_CUR);
+  ip->seek(8, librevenge::RVNG_SEEK_CUR);
   long size = ip->readLong(4);
 
-  if (size <= 0) return ip->atEOS();
+  if (size <= 0) return ip->isEnd();
 
   actPos = ip->tell();
-  if (ip->seek(actPos+size, WPX_SEEK_SET) != 0
+  if (ip->seek(actPos+size, librevenge::RVNG_SEEK_SET) != 0
       || ip->tell() != actPos+size)
     return false;
 
   return true;
 }
 
-bool MWAWOLEParser::readOlePres(MWAWInputStreamPtr ip, WPXBinaryData &data, MWAWPosition &pos,
+bool MWAWOLEParser::readOlePres(MWAWInputStreamPtr ip, librevenge::RVNGBinaryData &data, MWAWPosition &pos,
                                 libmwaw::DebugFile &ascii)
 {
   data.clear();
   if (!isOlePres(ip, "OlePres")) return false;
 
   pos = MWAWPosition();
-  pos.setUnit(WPX_POINT);
+  pos.setUnit(librevenge::RVNG_POINT);
   pos.setRelativePosition(MWAWPosition::Char);
   libmwaw::DebugStream f;
   f << "@@OlePress(header): ";
-  ip->seek(0,WPX_SEEK_SET);
+  ip->seek(0,librevenge::RVNG_SEEK_SET);
   for (int i = 0; i < 2; i++) {
     long val = ip->readLong(4);
     f << val << ", ";
@@ -811,11 +821,11 @@ bool MWAWOLEParser::readOlePres(MWAWInputStreamPtr ip, WPXBinaryData &data, MWAW
     ascii.addPos(actPos);
     ascii.addNote(f.str().c_str());
   }
-  if (ip->seek(endHPos+28, WPX_SEEK_SET) != 0
+  if (ip->seek(endHPos+28, librevenge::RVNG_SEEK_SET) != 0
       || ip->tell() != endHPos+28)
     return false;
 
-  ip->seek(endHPos, WPX_SEEK_SET);
+  ip->seek(endHPos, librevenge::RVNG_SEEK_SET);
 
   actPos = ip->tell();
   f.str("");
@@ -834,12 +844,12 @@ bool MWAWOLEParser::readOlePres(MWAWInputStreamPtr ip, WPXBinaryData &data, MWAW
   ascii.addPos(actPos);
   ascii.addNote(f.str().c_str());
 
-  if (fSize == 0) return ip->atEOS();
+  if (fSize == 0) return ip->isEnd();
 
   data.clear();
   if (!ip->readDataBlock(fSize, data)) return false;
 
-  if (!ip->atEOS()) {
+  if (!ip->isEnd()) {
     ascii.addPos(ip->tell());
     ascii.addNote("@@OlePress###");
   }
@@ -859,27 +869,27 @@ bool MWAWOLEParser::isOle10Native(MWAWInputStreamPtr ip, std::string const &oleN
 {
   if (strncmp("Ole10Native",oleName.c_str(),11) != 0) return false;
 
-  if (ip->seek(4, WPX_SEEK_SET) != 0 || ip->tell() != 4) return false;
+  if (ip->seek(4, librevenge::RVNG_SEEK_SET) != 0 || ip->tell() != 4) return false;
 
-  ip->seek(0, WPX_SEEK_SET);
+  ip->seek(0, librevenge::RVNG_SEEK_SET);
   long size = ip->readLong(4);
 
   if (size <= 0) return false;
-  if (ip->seek(4+size, WPX_SEEK_SET) != 0 || ip->tell() != 4+size)
+  if (ip->seek(4+size, librevenge::RVNG_SEEK_SET) != 0 || ip->tell() != 4+size)
     return false;
 
   return true;
 }
 
 bool MWAWOLEParser::readOle10Native(MWAWInputStreamPtr ip,
-                                    WPXBinaryData &data,
+                                    librevenge::RVNGBinaryData &data,
                                     libmwaw::DebugFile &ascii)
 {
   if (!isOle10Native(ip, "Ole10Native")) return false;
 
   libmwaw::DebugStream f;
   f << "@@Ole10Native(Header): ";
-  ip->seek(0,WPX_SEEK_SET);
+  ip->seek(0,librevenge::RVNG_SEEK_SET);
   long fSize = ip->readLong(4);
   f << "fSize=" << fSize;
 
@@ -889,7 +899,7 @@ bool MWAWOLEParser::readOle10Native(MWAWInputStreamPtr ip,
   data.clear();
   if (!ip->readDataBlock(fSize, data)) return false;
 
-  if (!ip->atEOS()) {
+  if (!ip->isEnd()) {
     ascii.addPos(ip->tell());
     ascii.addNote("@@Ole10Native###");
   }
@@ -911,7 +921,7 @@ bool MWAWOLEParser::readOle10Native(MWAWInputStreamPtr ip,
 ////////////////////////////////////////////////////////////////
 bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
                                  std::string const &oleName,
-                                 WPXBinaryData &pict, MWAWPosition &pos,
+                                 librevenge::RVNGBinaryData &pict, MWAWPosition &pos,
                                  libmwaw::DebugFile &ascii)
 {
   pict.clear();
@@ -919,9 +929,9 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
 
   libmwaw::DebugStream f;
   pos = MWAWPosition();
-  pos.setUnit(WPX_POINT);
+  pos.setUnit(librevenge::RVNG_POINT);
   pos.setRelativePosition(MWAWPosition::Char);
-  input->seek(0, WPX_SEEK_SET);
+  input->seek(0, librevenge::RVNG_SEEK_SET);
   f << "@@Contents:";
 
   bool ok = true;
@@ -945,7 +955,7 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
   naturalSize[1] = input->readLong(4);
   f << std::dec << "bdbox1=(" << naturalSize[0] << "," << naturalSize[1]<<"),";
   f << "unk=" << input->readULong(4) << ","; // 24 or 32
-  if (input->atEOS()) {
+  if (input->isEnd()) {
     MWAW_DEBUG_MSG(("MWAWOLEParser: warning: Contents header length\n"));
     return false;
   }
@@ -966,8 +976,8 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
   long size = (long) input->readULong(4);
   if (size <= 0) ok = false;
   if (ok) {
-    input->seek(actPos+size+4, WPX_SEEK_SET);
-    if (input->tell() != actPos+size+4 || !input->atEOS()) {
+    input->seek(actPos+size+4, librevenge::RVNG_SEEK_SET);
+    if (input->tell() != actPos+size+4 || !input->isEnd()) {
       ok = false;
       MWAW_DEBUG_MSG(("MWAWOLEParser: warning: Contents unexpected file size=%ld\n",
                       size));
@@ -980,18 +990,18 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
   ascii.addPos(0);
   ascii.addNote(f.str().c_str());
 
-  input->seek(actPos+4, WPX_SEEK_SET);
+  input->seek(actPos+4, librevenge::RVNG_SEEK_SET);
 
   if (ok) {
     if (input->readDataBlock(size, pict))
       ascii.skipZone(actPos+4, actPos+size+4-1);
     else {
-      input->seek(actPos+4, WPX_SEEK_SET);
+      input->seek(actPos+4, librevenge::RVNG_SEEK_SET);
       ok = false;
     }
   }
 
-  if (!input->atEOS()) {
+  if (!input->isEnd()) {
     ascii.addPos(actPos);
     ascii.addNote("@@Contents:###");
   }
@@ -1010,7 +1020,7 @@ bool MWAWOLEParser::readContents(MWAWInputStreamPtr input,
 ////////////////////////////////////////////////////////////////
 bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
                                  std::string const &oleName,
-                                 WPXBinaryData &pict, MWAWPosition &pos,
+                                 librevenge::RVNGBinaryData &pict, MWAWPosition &pos,
                                  libmwaw::DebugFile &ascii)
 {
   pict.clear();
@@ -1019,16 +1029,16 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
   libmwaw::DebugStream f;
 
   pos = MWAWPosition();
-  pos.setUnit(WPX_POINT);
+  pos.setUnit(librevenge::RVNG_POINT);
   pos.setRelativePosition(MWAWPosition::Char);
-  input->seek(0, WPX_SEEK_SET);
+  input->seek(0, librevenge::RVNG_SEEK_SET);
   f << "@@CONTENTS:";
 
   long hSize = (long)input->readULong(4);
-  if (input->atEOS()) return false;
+  if (input->isEnd()) return false;
   f << "hSize=" << std::hex << hSize << std::dec;
 
-  if (hSize <= 52 || input->seek(hSize+8,WPX_SEEK_SET) != 0
+  if (hSize <= 52 || input->seek(hSize+8,librevenge::RVNG_SEEK_SET) != 0
       || input->tell() != hSize+8) {
     MWAW_DEBUG_MSG(("MWAWOLEParser: warning: CONTENTS headerSize=%ld\n",
                     hSize));
@@ -1036,7 +1046,7 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
   }
 
   // minimal checking of the "copied" header
-  input->seek(4, WPX_SEEK_SET);
+  input->seek(4, librevenge::RVNG_SEEK_SET);
   long type = (long) input->readULong(4);
   if (type < 0 || type > 4) return false;
   long newSize = (long) input->readULong(4);
@@ -1095,14 +1105,14 @@ bool MWAWOLEParser::readCONTENTS(MWAWInputStreamPtr input,
   }
   ascii.addNote(f.str().c_str());
 
-  if (dataLength <= 0 || input->seek(hSize+4+dataLength,WPX_SEEK_SET) != 0
-      || input->tell() != hSize+4+dataLength || !input->atEOS()) {
+  if (dataLength <= 0 || input->seek(hSize+4+dataLength,librevenge::RVNG_SEEK_SET) != 0
+      || input->tell() != hSize+4+dataLength || !input->isEnd()) {
     MWAW_DEBUG_MSG(("MWAWOLEParser: warning: CONTENTS unexpected file length=%ld\n",
                     dataLength));
     return false;
   }
 
-  input->seek(4+hSize, WPX_SEEK_SET);
+  input->seek(4+hSize, librevenge::RVNG_SEEK_SET);
   if (!input->readEndDataBlock(pict)) return false;
 
   ascii.skipZone(hSize+4, input->tell()-1);
